# Generated by Django 3.1 on 2020-09-15 14:45

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='Directory',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('dn', models.CharField(max_length=100)),
                ('dc', models.GenericIPAddressField()),
                ('username', models.CharField(max_length=100)),
                ('password', models.CharField(max_length=100)),
                ('ldaps', models.BooleanField(default=False)),
            ],
        ),
        migrations.CreateModel(
            name='Query',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(blank=True, max_length=50, null=True)),
                ('query', models.CharField(max_length=200)),
                ('base_dn', models.CharField(blank=True, max_length=200, null=True, verbose_name='Base DN')),
                ('type', models.CharField(choices=[('user', 'User'), ('computer', 'Computer'), ('group', 'Group')], max_length=15)),
                ('target', models.CharField(choices=[('ad_import.Workstation', 'Workstation'), ('costs.Server', 'Server'), ('costs.User', 'User'), ('ad_import.Group', 'Group')], max_length=200)),
                ('directory', models.ForeignKey(on_delete=django.db.models.deletion.PROTECT, to='ad_import.directory')),
            ],
            options={
                'verbose_name': 'LDAP query',
                'verbose_name_plural': 'LDAP queries',
            },
        ),
    ]
