# Generated by Django 3.1 on 2020-09-17 20:01

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('ad_import', '0001_initial'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='directory',
            options={'verbose_name_plural': 'directories'},
        ),
        migrations.AddField(
            model_name='directory',
            name='name',
            field=models.CharField(blank=True, max_length=100, null=True),
        ),
        migrations.AlterField(
            model_name='query',
            name='directory',
            field=models.ForeignKey(on_delete=django.db.models.deletion.PROTECT, related_name='queries', to='ad_import.directory'),
        ),
        migrations.AlterField(
            model_name='query',
            name='target',
            field=models.CharField(choices=[('ad_import.Workstation', 'Workstation'), ('costs.Server', 'Server'), ('ad_import.User', 'User'), ('ad_import.Group', 'Group')], max_length=200),
        ),
        migrations.CreateModel(
            name='User',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('accountExpires', models.DateTimeField(null=True, verbose_name='konto utløper')),
                ('cn', models.CharField(blank=True, max_length=255, null=True, verbose_name='fullt navn')),
                ('company', models.CharField(blank=True, max_length=255, null=True, verbose_name='firma')),
                ('department', models.CharField(blank=True, max_length=255, null=True, verbose_name='avdeling')),
                ('departmentNumber', models.CharField(blank=True, max_length=255, null=True, verbose_name='avdelingsnummer')),
                ('description', models.CharField(blank=True, max_length=255, null=True, verbose_name='beskrivelse')),
                ('displayName', models.CharField(blank=True, max_length=255, null=True, verbose_name='visningsnavn')),
                ('distinguishedName', models.CharField(blank=True, max_length=300, null=True, verbose_name='DN')),
                ('employeeID', models.CharField(blank=True, max_length=255, null=True)),
                ('employeeNumber', models.CharField(blank=True, max_length=255, null=True)),
                ('givenName', models.CharField(blank=True, max_length=255, null=True, verbose_name='fornavn')),
                ('homeDirectory', models.CharField(blank=True, max_length=255, null=True)),
                ('homeDrive', models.CharField(blank=True, max_length=255, null=True)),
                ('ipPhone', models.CharField(blank=True, max_length=255, null=True, verbose_name='IP-telefon')),
                ('lastLogon', models.DateTimeField(blank=True, null=True, verbose_name='siste pålogging')),
                ('logonCount', models.IntegerField(null=True, verbose_name='Antall pålogginger')),
                ('mail', models.EmailField(max_length=254, null=True, verbose_name='Epostadresse')),
                ('middleName', models.CharField(blank=True, max_length=255, null=True, verbose_name='mellomnavn')),
                ('mobile', models.CharField(blank=True, max_length=255, null=True, verbose_name='mobil')),
                ('name', models.CharField(blank=True, max_length=255, null=True, verbose_name='Navn')),
                ('objectGUID', models.CharField(blank=True, max_length=255, null=True)),
                ('objectSid', models.CharField(blank=True, max_length=255, null=True)),
                ('physicalDeliveryOfficeName', models.CharField(blank=True, max_length=255, null=True, verbose_name='Lokasjon')),
                ('pwdLastSet', models.DateTimeField(null=True, verbose_name='passord sist endret')),
                ('sAMAccountName', models.CharField(blank=True, max_length=255, null=True, verbose_name='brukernavn')),
                ('scriptPath', models.CharField(blank=True, max_length=255, null=True)),
                ('sn', models.CharField(blank=True, max_length=255, null=True, verbose_name='etternavn')),
                ('telephoneNumber', models.CharField(blank=True, max_length=255, null=True)),
                ('title', models.CharField(blank=True, max_length=255, null=True)),
                ('userAccountControl', models.IntegerField(null=True)),
                ('userPrincipalName', models.CharField(blank=True, max_length=255, null=True)),
                ('whenChanged', models.DateTimeField(null=True, verbose_name='sist endret')),
                ('whenCreated', models.DateTimeField(null=True, verbose_name='opprettet')),
                ('last_update', models.DateTimeField(auto_now=True, verbose_name='sist oppdatert')),
                ('directory', models.ForeignKey(on_delete=django.db.models.deletion.PROTECT, to='ad_import.directory')),
                ('manager', models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, to='ad_import.user', verbose_name='Leder')),
            ],
        ),
    ]
