# Generated by Django 3.1 on 2020-09-18 11:51

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('ad_import', '0002_auto_20200917_2001'),
    ]

    operations = [
        migrations.CreateModel(
            name='Workstation',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('cn', models.CharField(blank=True, max_length=255, null=True)),
                ('description', models.CharField(blank=True, max_length=255, null=True, verbose_name='beskrivelse')),
                ('distinguishedName', models.CharField(blank=True, max_length=300, null=True, verbose_name='DN')),
                ('lastLogon', models.DateTimeField(blank=True, null=True, verbose_name='siste pålogging')),
                ('logonCount', models.IntegerField(null=True, verbose_name='Antall pålogginger')),
                ('name', models.CharField(blank=True, max_length=255, null=True, verbose_name='navn')),
                ('objectGUID', models.CharField(blank=True, max_length=255, null=True)),
                ('objectSid', models.CharField(blank=True, max_length=255, null=True)),
                ('operatingSystem', models.CharField(blank=True, max_length=255, null=True, verbose_name='Operativsystem')),
                ('operatingSystemHotfix', models.CharField(blank=True, max_length=255, null=True)),
                ('operatingSystemServicePack', models.CharField(blank=True, max_length=255, null=True)),
                ('operatingSystemVersion', models.CharField(blank=True, max_length=255, null=True)),
                ('pwdLastSet', models.DateTimeField(null=True, verbose_name='passord sist endret')),
                ('userAccountControl', models.IntegerField(null=True)),
                ('whenChanged', models.DateTimeField(null=True, verbose_name='sist endret')),
                ('whenCreated', models.DateTimeField(null=True, verbose_name='opprettet')),
                ('last_update', models.DateTimeField(auto_now=True, verbose_name='sist oppdatert')),
                ('directory', models.ForeignKey(on_delete=django.db.models.deletion.PROTECT, to='ad_import.directory')),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='Server',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('cn', models.CharField(blank=True, max_length=255, null=True)),
                ('description', models.CharField(blank=True, max_length=255, null=True, verbose_name='beskrivelse')),
                ('distinguishedName', models.CharField(blank=True, max_length=300, null=True, verbose_name='DN')),
                ('lastLogon', models.DateTimeField(blank=True, null=True, verbose_name='siste pålogging')),
                ('logonCount', models.IntegerField(null=True, verbose_name='Antall pålogginger')),
                ('name', models.CharField(blank=True, max_length=255, null=True, verbose_name='navn')),
                ('objectGUID', models.CharField(blank=True, max_length=255, null=True)),
                ('objectSid', models.CharField(blank=True, max_length=255, null=True)),
                ('operatingSystem', models.CharField(blank=True, max_length=255, null=True, verbose_name='Operativsystem')),
                ('operatingSystemHotfix', models.CharField(blank=True, max_length=255, null=True)),
                ('operatingSystemServicePack', models.CharField(blank=True, max_length=255, null=True)),
                ('operatingSystemVersion', models.CharField(blank=True, max_length=255, null=True)),
                ('pwdLastSet', models.DateTimeField(null=True, verbose_name='passord sist endret')),
                ('userAccountControl', models.IntegerField(null=True)),
                ('whenChanged', models.DateTimeField(null=True, verbose_name='sist endret')),
                ('whenCreated', models.DateTimeField(null=True, verbose_name='opprettet')),
                ('last_update', models.DateTimeField(auto_now=True, verbose_name='sist oppdatert')),
                ('directory', models.ForeignKey(on_delete=django.db.models.deletion.PROTECT, to='ad_import.directory')),
            ],
            options={
                'abstract': False,
            },
        ),
    ]
